Summary:       Tool for managing bootable, immutable filesystem trees
Name:          ostree
Version:       2023.3
Release:       5%{?dist}
License:       LGPLv2+
URL:           https://ostree.readthedocs.io/en/latest/
Source0:       https://github.com/ostreedev/%{name}/releases/download/v%{version}/libostree-%{version}.tar.xz

BuildRequires: make autoconf automake libtool git gtk-doc
BuildRequires: openssl-devel libattr-devel libcap-devel gpgme-devel
BuildRequires: dracut bison
BuildRequires: /usr/bin/g-ir-scanner
BuildRequires: pkgconfig(zlib)
BuildRequires: pkgconfig(libcurl)
BuildRequires: pkgconfig(libarchive)
BuildRequires: pkgconfig(liblzma)
BuildRequires: pkgconfig(libselinux)
BuildRequires: pkgconfig(mount)
BuildRequires: pkgconfig(fuse3)
BuildRequires: pkgconfig(e2p)
BuildRequires: pkgconfig(libsystemd)

Requires:      dracut systemd-units
Requires:      /usr/bin/gpgv2
Requires:      %{name}-libs = %{version}-%{release}

%description
libostree is both a shared library and suite of command line tools that
combines a “git-like” model for committing and downloading bootable
filesystem trees, along with a layer for deploying them and managing
the bootloader configuration.

%package       libs
Summary:       C shared libraries %{name}

%description   libs
This package provides shared libraries for ostree

%package       devel
Summary:       Development headers for %{name}
Requires:      %{name}-libs = %{version}-%{release}

%description   devel
This package includes the header files for the ostree library

%package       grub2
Summary:       GRUB2 integration for OSTree
Requires:      ostree
%ifnarch aarch64 loongarch64
Requires:      grub2
%else
Requires:      grub2-efi
%endif

%description   grub2
GRUB2 integration for OSTree

%prep
%autosetup -Sgit -n libostree-%{version}

%build
env NOCONFIGURE=1 ./autogen.sh
%configure --disable-silent-rules     \
           --enable-gtk-doc           \
           --with-selinux             \
           --with-curl                \
           --with-openssl             \
           --with-dracut=yesbutnoconf \
           --with-soup=no
%make_build

%install
%make_install
find %{buildroot} -name '*.la' -delete

# do not provides html files
rm -rf %{buildroot}%{_datadir}/gtk-doc/html

%post
%systemd_post ostree-remount.service

%preun
%systemd_preun ostree-remount.service

%files
%license COPYING
%doc README.md
%{_bindir}/ostree
%{_bindir}/rofiles-fuse
%{_datadir}/ostree
%{_datadir}/bash-completion/completions/*
%dir %{_prefix}/lib/dracut/modules.d/98ostree
%{_prefix}/lib/systemd/system/ostree*.*
%{_prefix}/lib/dracut/modules.d/98ostree/*
%{_prefix}/lib/systemd/system-generators/ostree-system-generator
%{_prefix}/lib/tmpfiles.d/*
%{_prefix}/lib/ostree
%{_libexecdir}/libostree/*
%{_mandir}/man*/*.gz
%exclude %{_sysconfdir}/grub.d/*ostree
%exclude %{_libexecdir}/libostree/grub2*

%files libs
%{_sysconfdir}/ostree
%{_libdir}/*.so.1*
%{_libdir}/girepository-1.0/OSTree-1.0.typelib

%files devel
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*
%{_datadir}/gir-1.0/OSTree-1.0.gir

%files grub2
%{_sysconfdir}/grub.d/*ostree
%dir %{_libexecdir}/libostree
%{_libexecdir}/libostree/grub2*

%changelog
* Mon Mar 18 2024 Huang Yang <huangyang@loongson.cn> - 2023.3-5
- fix install error for loongarch64

* Thu Oct 12 2023 Miaojun Dong <zoedong@tencent.com> - 2023.3-4
- Rebuild for curl-8.4.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2023.3-3
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Jul 12 2023 cunshunxia <cunshunxia@tencent.com> - 2023.3-2
- pack files because gobject-introspection upgrade.

* Wed Jul 12 2023 cunshunxia <cunshunxia@tencent.com> - 2023.3-1
- upgrade to 2023.3

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2022.5-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2022.5-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Oct 10 2022 Shuo Wang <abushwang@tencent.com> - 2022.5-1
- initial build

